==> pegasus-merchandise-api-1.3.1-sources.jar: com/thebeastshop/pegasus/merchandise/cond/OpLabelCond.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.pegasus.util.cond.BaseQueryCond;

import java.io.Serializable;
import java.util.List;

/**
 * @Author: LK【kai.li@thebeastshop.com】
 * @Date: 2016/12/30 11:10 
 */
public class OpLabelCond extends BaseQueryCond implements Serializable {

    public OpLabelCond() {
        super();
    }

    private String categoryCode; //类目code

    private Long categoryId; //类目Id

    private List<Long> brandIds; //标签

    private List<Long> categoryIds; //类目Ids

    private String channelCode; //渠道

    private Integer isCrossBorder; //是否海淘

    private List<Long> labelIds; //标签

    public String getCategoryCode() {
        return categoryCode;
    }

    public void setCategoryCode(String categoryCode) {
        this.categoryCode = categoryCode;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public List<Long> getBrandIds() {
        return brandIds;
    }

    public void setBrandIds(List<Long> brandIds) {
        this.brandIds = brandIds;
    }

    public List<Long> getCategoryIds() {
        return categoryIds;
    }

    public void setCategoryIds(List<Long> categoryIds) {
        this.categoryIds = categoryIds;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public Integer getIsCrossBorder() {
        return isCrossBorder;
    }

    public void setIsCrossBorder(Integer isCrossBorder) {
        this.isCrossBorder = isCrossBorder;
    }

    public List<Long> getLabelIds() {
        return labelIds;
    }

    public void setLabelIds(List<Long> labelIds) {
        this.labelIds = labelIds;
    }
}

==> pegasus-merchandise-api-1.6.5-sources.jar: com/thebeastshop/pegasus/merchandise/cond/OpLabelCond.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.pegasus.util.cond.BaseQueryCond;

import java.io.Serializable;
import java.util.List;

/**
 * @Author: LK【kai.li@thebeastshop.com】
 * @Date: 2016/12/30 11:10 
 */
public class OpLabelCond extends BaseQueryCond implements Serializable {

    public OpLabelCond() {
        super();
    }

    private String categoryCode; //类目code

    private Long categoryId; //类目Id

    private List<Long> brandIds; //标签

    private List<Long> categoryIds; //类目Ids

    private String channelCode; //渠道

    private Integer isCrossBorder; //是否海淘

    private List<Long> labelIds; //标签

    private String splice;

    public String getCategoryCode() {
        return categoryCode;
    }

    public void setCategoryCode(String categoryCode) {
        this.categoryCode = categoryCode;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public List<Long> getBrandIds() {
        return brandIds;
    }

    public void setBrandIds(List<Long> brandIds) {
        this.brandIds = brandIds;
    }

    public List<Long> getCategoryIds() {
        return categoryIds;
    }

    public void setCategoryIds(List<Long> categoryIds) {
        this.categoryIds = categoryIds;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public Integer getIsCrossBorder() {
        return isCrossBorder;
    }

    public void setIsCrossBorder(Integer isCrossBorder) {
        this.isCrossBorder = isCrossBorder;
    }

    public List<Long> getLabelIds() {
        return labelIds;
    }

    public void setLabelIds(List<Long> labelIds) {
        this.labelIds = labelIds;
    }

    public String getSplice() {
        return splice;
    }

    public void setSplice(String splice) {
        this.splice = splice;
    }
}
